==> amarok_2.6.0.orig.tar.bz2: amarok-2.6.0/src/core/capabilities/WriteLabelCapability.h <==
/****************************************************************************************
 * Copyright (C) 2009 Dan Meltzer <parallelgrapefruit@gmail.com>                        *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef WRITELABELCAPABILITY_H
#define WRITELABELCAPABILITY_H

#include "core/capabilities/Capability.h"
#include "core/meta/Meta.h"
#include "shared/amarok_export.h"

namespace Capabilities
{

class AMAROK_CORE_EXPORT WriteLabelCapability : public Capabilities::Capability
{
    Q_OBJECT
    public:
        static Type capabilityInterfaceType() { return Capabilities::Capability::WriteLabel; }

        //Implementors
        virtual void setLabels( const QStringList &removedLabels, const QStringList &labels ) = 0;

};

}
#endif // READLABELCAPABILITY_H

==> amarok-2.7.1.tar.bz2: amarok-2.7.1/src/core/capabilities/WriteLabelCapability.h <==
/****************************************************************************************
 * Copyright (C) 2009 Dan Meltzer <parallelgrapefruit@gmail.com>                        *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef WRITELABELCAPABILITY_H
#define WRITELABELCAPABILITY_H

#include "amarok_export.h"
#include "core/capabilities/Capability.h"
#include "core/meta/Meta.h"

namespace Capabilities
{

class AMAROK_CORE_EXPORT WriteLabelCapability : public Capabilities::Capability
{
    Q_OBJECT
    public:
        static Type capabilityInterfaceType() { return Capabilities::Capability::WriteLabel; }

        //Implementors
        virtual void setLabels( const QStringList &removedLabels, const QStringList &labels ) = 0;

};

}
#endif // READLABELCAPABILITY_H
